@@ -3,6 +3,7 @@
 
 
 import locale
+import logging  # Import the logging module
 from pathlib import Path
 from typing import Any, Tuple, Union
 
@@ -18,11 +19,16 @@ from slpkg.views.version import Version
 
 locale.setlocale(locale.LC_ALL, '')
 
+# Initialize the logger for this module.
+# This allows for hierarchical logging and clear identification of log message origin.
+logger = logging.getLogger(__name__)
+
 
 class DialogBox:
     """Class for dialog box."""
 
     def __init__(self) -> None:
+        logger.debug("Initializing DialogBox class.")
         self.prog_name = config_load.prog_name
         self.more_kwargs: dict[str, bool] = {}
 
@@ -30,8 +36,10 @@ class DialogBox:
             self.d = Dialog(dialog="dialog")
             self.d.add_persistent_args(["--colors"])
             self.d.set_background_title(f'{self.prog_name} {Version().version} - Software Package Manager')
+            logger.debug("Dialog utility is available and initialized. Background title set to: '%s %s - Software Package Manager'", self.prog_name, Version().version)
         else:
             self.d = None
+            logger.warning("Python 'dialog' module is not available. DialogBox functionality will be limited.")
 
     def checklist(self, text: str, title: str, height: int, width: int, list_height: int, choices: list[tuple[Any, ...]]) -> Tuple[str, list[str]]:  # pylint: disable=[R0913, R0917]
         """Display a checklist box.
@@ -51,18 +59,22 @@ class DialogBox:
                               second element lists all tags for the entries selected by the user.
                               If the user exits with Esc or Cancel, the returned tag list is empty.
         """
+        logger.info("Displaying checklist dialog with title: '%s', text: '%s', %d choices.", title, text, len(choices))
+        if not self.d:
+            logger.error("Dialog object is not initialized. Cannot display checklist.")
+            return '', []  # Return empty if dialog is not available.
+
         self.more_kwargs.update(
             {"item_help": True}
         )
 
         code, tags = self.d.checklist(text=text, choices=choices, title=title, height=height, width=width,
-                                      # pylint: disable=[R0913, R0917]
                                       list_height=list_height, help_status=True, **self.more_kwargs)
 
+        logger.info("Checklist dialog exited with code: '%s', selected tags: %s", code, tags)
         return code, tags
 
-    def mixedform(self, text: str, title: str, elements: list[str], height: int, width: int, form_height: int) -> Tuple[
-        bool, list[str]]:  # pylint: disable=[R0913, R0917]
+    def mixedform(self, text: str, title: str, elements: list[str], height: int, width: int, form_height: int) -> Tuple[str, list[str]]:  # pylint: disable=[R0913, R0917]
         """Display a mixedform box.
 
         Args:
@@ -74,10 +86,15 @@ class DialogBox:
             form_height (int): Number of form lines displayed at the same time.
 
         Returns:
-            Tuple[bool, list]: a tuple of the form (code, list) where:
+            Tuple[str, list]: a tuple of the form (code, list) where:
                                - code is a Dialog exit code;
                                - list gives the contents of every field on exit, with the same order as in elements.
         """
+        logger.info("Displaying mixedform dialog with title: '%s', text: '%s', %d elements.", title, text, len(elements))
+        if not self.d:
+            logger.error("Dialog object is not initialized. Cannot display mixedform.")
+            return '', []  # Return empty if dialog is not available.
+
         self.more_kwargs.update(
             {"item_help": True,
              "help_tags": True}
@@ -86,6 +103,7 @@ class DialogBox:
                                       height=height, width=width, form_height=form_height, help_button=True,
                                       help_status=True, **self.more_kwargs)
 
+        logger.info("Mixedform dialog exited with code: '%s', returned tags: %s", code, tags)
         return code, tags
 
     def msgbox(self, text: str, height: int, width: int) -> None:
@@ -96,7 +114,14 @@ class DialogBox:
             height (int): Height of the box.
             width (int): Width of the box.
         """
+        logger.info("Displaying message box with text: '%s' (Height: %d, Width: %d).", text, height, width)
+        if not self.d:
+            logger.error("Dialog object is not initialized. Cannot display message box. Message: '%s'", text)
+            print(f"ERROR: Cannot display dialog message box. Message: {text}")  # Fallback print to console.
+            return
+
         self.d.msgbox(text, height, width)
+        logger.debug("Message box closed.")
 
     def textbox(self, text: Union[str, Path], height: int, width: int) -> None:
         """Display a text box.
@@ -106,4 +131,11 @@ class DialogBox:
             height (int): Height of the box.
             width (int): Width of the box.
         """
-        self.d.textbox(text, height, width)
+        logger.info("Displaying textbox with content from: '%s' (Height: %d, Width: %d).", text, height, width)
+        if not self.d:
+            logger.error("Dialog object is not initialized. Cannot display textbox. Content: '%s'", text)
+            print(f"ERROR: Cannot display dialog textbox. Content: {text}")  # Fallback print to console.
+            return
+
+        self.d.textbox(str(text), height, width)
+        logger.debug("Textbox closed.")
