@@ -306,7 +306,10 @@ class InstallData:
 
             elif line.startswith(pkg_tag[1]):  # PACKAGE LOCATION:
                 package_location = line.replace(pkg_tag[1], '').strip()
-                cache.append(package_location[2:])  # Do not install (.) dot
+                if repo == self.repos.slack_testing_repo_name:
+                    cache.append(package_location.replace('./testing/', ''))
+                else:
+                    cache.append(package_location[2:])  # Do not install (.) dot
                 logger.debug("Package location: %s", package_location[2:])
 
             elif line.startswith(pkg_tag[2]):  # PACKAGE SIZE (compressed):
