@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
+# pylint: disable=[C0302]
 
 import argparse
 import logging
@@ -581,11 +582,11 @@ class CustomCommandsFormatter(argparse.RawDescriptionHelpFormatter):
     - Clean command listing with proper indentation
     """
 
-    def __init__(self, prog: str, indent_increment: int = 1, max_help_position: int = 18, width: Union[int, None] = None) -> None:
+    def __init__(self, prog: str, indent_increment: int = 1, max_help_position: int = 26, width: Union[int, None] = None) -> None:
         super().__init__(prog, indent_increment, max_help_position, width)
-        self._subcommands = ['update', 'upgrade', 'config', 'repo-info', 'clean-tmp',
-                             'self-check', 'build', 'install', 'remove', 'download',
-                             'list', 'info', 'search', 'dependees', 'tracking', 'version', 'changelog', 'help']
+        # self._subcommands = ['update', 'upgrade', 'config', 'repo-info', 'clean-tmp',
+        #                      'self-check', 'build', 'install', 'remove', 'download',
+        #                      'list', 'info', 'search', 'dependees', 'tracking', 'version', 'changelog', 'help']
         self.custom_usage = f"{self._prog} <COMMAND> [PACKAGES] [OPTIONS]"
         logger.debug("CustomCommandsFormatter initialized.")
 
@@ -655,13 +656,30 @@ def main() -> None:  # pylint: disable=[R0912,R0914,R0915]
     error = Errors()
 
     commands_that_use_repos = [
-        'install', 'build', 'download', 'info', 'search',
-        'dependees', 'tracking', 'update', 'upgrade', 'repo-info', 'changelog'
+        'install', 'i', 'inst',
+        'build', 'b', 'bld',
+        'download', 'dl', 'dwn',
+        'info', 'inf', 'show',
+        'search', 's', 'ser',
+        'dependees', 'dp', 'dps',
+        'tracking', 't', 'trk',
+        'update', 'u', 'upd',
+        'upgrade', 'U', 'upg',
+        'repo-info', 'ri', 'rinf',
+        'changelog', 'a', 'chg'
     ]
     logger.debug("Commands that use repositories: %s", commands_that_use_repos)
 
     commands_that_use_packages = [
-        'install', 'remove', 'build', 'download', 'info', 'search', 'list', 'dependees', 'tracking'
+        'install', 'i', 'inst',
+        'remove', 'R', 'rmv',
+        'build', 'b', 'bld',
+        'download', 'dl', 'dwn',
+        'info', 'inf', 'show',
+        'search', 's', 'ser',
+        'list', 'l', 'lst',
+        'dependees', 'dp', 'dps',
+        'tracking', 't', 'trk'
     ]
     logger.debug("Commands that use packages: %s", commands_that_use_packages)
 
@@ -783,66 +801,66 @@ def main() -> None:  # pylint: disable=[R0912,R0914,R0915]
 
     # --- Subcommand Parsers ---
     # Store each subparser in the map after creation
-    subparsers_map['update'] = subparsers.add_parser('update', parents=[check_parser, color_parser, repository_parser, debug_parser], help='Sync repository database with local.')
-    subparsers_map['upgrade'] = subparsers.add_parser('upgrade', parents=[yes_parser, check_parser, resolve_off_parser, progress_bar_parser, parallel_parser, dialog_parser, color_parser, repository_parser, debug_parser],
+    subparsers_map['update'] = subparsers.add_parser('update', aliases=['u', 'upd'], parents=[check_parser, color_parser, repository_parser, debug_parser], help='Sync repository database with local.')
+    subparsers_map['upgrade'] = subparsers.add_parser('upgrade', aliases=['U', 'upg'], parents=[yes_parser, check_parser, resolve_off_parser, progress_bar_parser, parallel_parser, dialog_parser, color_parser, repository_parser, debug_parser],
                                                       help='Upgrade the installed packages.')
-    subparsers_map['config'] = subparsers.add_parser('config', parents=[edit_parser, dialog_parser, debug_parser], help='Edit the configuration file.')
-    subparsers_map['repo-info'] = subparsers.add_parser('repo-info', parents=[fetch_parser, color_parser, repository_parser, debug_parser], help='Display the repositories information.')
-    subparsers_map['clean-tmp'] = subparsers.add_parser('clean-tmp', parents=[debug_parser], help='Clean old downloaded packages and scripts.')
-    subparsers_map['self-check'] = subparsers.add_parser('self-check', parents=[debug_parser], help='Checks for available slpkg updates.')
+    subparsers_map['config'] = subparsers.add_parser('config', aliases=['g', 'conf'], parents=[edit_parser, dialog_parser, debug_parser], help='Edit the configuration file.')
+    subparsers_map['repo-info'] = subparsers.add_parser('repo-info', aliases=['ri', 'rinf'], parents=[fetch_parser, color_parser, repository_parser, debug_parser], help='Display the repositories information.')
+    subparsers_map['clean-tmp'] = subparsers.add_parser('clean-tmp', aliases=['c', 'ctmp'], parents=[debug_parser], help='Clean old downloaded packages and scripts.')
+    subparsers_map['self-check'] = subparsers.add_parser('self-check', aliases=['sc', 'schk'], parents=[debug_parser], help='Checks for available slpkg updates.')
 
-    build_parser = subparsers.add_parser('build', parents=[yes_parser, resolve_off_parser, skip_install_parser, progress_bar_parser, parallel_parser, no_case_parser, select_parser, dialog_parser, edit_sbo_parser, repo_tag_parser, color_parser,
-                                                           repository_parser, debug_parser],
+    build_parser = subparsers.add_parser('build', aliases=['b', 'bld'], parents=[yes_parser, resolve_off_parser, skip_install_parser, progress_bar_parser, parallel_parser, no_case_parser, select_parser, dialog_parser, edit_sbo_parser, repo_tag_parser, color_parser,
+                                         repository_parser, debug_parser],
                                          help='Build SBo scripts without install it.')
     build_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to build.')
     subparsers_map['build'] = build_parser
 
-    install_parser = subparsers.add_parser('install', parents=[yes_parser, reinstall_parser, resolve_off_parser, skip_install_parser, progress_bar_parser, parallel_parser, no_case_parser,
+    install_parser = subparsers.add_parser('install', aliases=['i', 'inst'], parents=[yes_parser, reinstall_parser, resolve_off_parser, skip_install_parser, progress_bar_parser, parallel_parser, no_case_parser,
                                            select_parser, dialog_parser, edit_sbo_parser, repo_tag_parser, color_parser, repository_parser, debug_parser],
                                            help='Build/install SBo scripts or binary packages.')
     install_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to install.')
     subparsers_map['install'] = install_parser
 
-    remove_parser = subparsers.add_parser('remove', parents=[yes_parser, resolve_off_parser, select_parser, dialog_parser, progress_bar_parser, color_parser, debug_parser],
+    remove_parser = subparsers.add_parser('remove', aliases=['R', 'rmv'], parents=[yes_parser, resolve_off_parser, select_parser, dialog_parser, progress_bar_parser, color_parser, debug_parser],
                                           help='Remove installed packages with dependencies.')
     remove_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to remove.')
     subparsers_map['remove'] = remove_parser
 
-    download_parser = subparsers.add_parser('download', parents=[yes_parser, no_case_parser, select_parser, dialog_parser, color_parser, directory_parser, repository_parser, debug_parser],
+    download_parser = subparsers.add_parser('download', aliases=['dl', 'dwn'], parents=[yes_parser, no_case_parser, select_parser, dialog_parser, color_parser, directory_parser, repository_parser, debug_parser],
                                             help='Download only the packages without build or install.')
     download_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to download.')
     subparsers_map['download'] = download_parser
 
-    list_parser = subparsers.add_parser('list', parents=[no_case_parser, description_parser, select_parser, dialog_parser, color_parser, debug_parser], help='Matching and display list of the installed packages.')
+    list_parser = subparsers.add_parser('list', aliases=['l', 'lst'], parents=[no_case_parser, description_parser, select_parser, dialog_parser, color_parser, debug_parser], help='Matching and display list of the installed packages.')
     list_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to display.')
     subparsers_map['list'] = list_parser
 
-    info_parser = subparsers.add_parser('info', parents=[select_parser, dialog_parser, color_parser, repository_parser, debug_parser], help='Display package information by the repository.')
+    info_parser = subparsers.add_parser('info', aliases=['inf', 'show'], parents=[select_parser, dialog_parser, color_parser, repository_parser, debug_parser], help='Display package information by the repository.')
     info_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to display information for.')
     subparsers_map['info'] = info_parser
 
-    search_parser = subparsers.add_parser('search', parents=[no_case_parser, pkg_version_parser, description_parser, select_parser, dialog_parser, color_parser, repository_parser, debug_parser],
+    search_parser = subparsers.add_parser('search', aliases=['s', 'ser'], parents=[no_case_parser, pkg_version_parser, description_parser, select_parser, dialog_parser, color_parser, repository_parser, debug_parser],
                                           help='This will match each package by the repository.')
     search_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names to search for.')
     subparsers_map['search'] = search_parser
 
-    dependees_parser = subparsers.add_parser('dependees', parents=[no_case_parser, pkg_version_parser, full_reverse_parser, select_parser, dialog_parser, color_parser, repository_parser, debug_parser],
+    dependees_parser = subparsers.add_parser('dependees', aliases=['dp', 'dps'], parents=[no_case_parser, pkg_version_parser, full_reverse_parser, select_parser, dialog_parser, color_parser, repository_parser, debug_parser],
                                              help='Display packages that depend on other packages.')
     dependees_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names for dependencies.')
     subparsers_map['dependees'] = dependees_parser
 
-    tracking_parser = subparsers.add_parser('tracking', parents=[no_case_parser, pkg_version_parser, select_parser, dialog_parser, color_parser, repository_parser, debug_parser],
+    tracking_parser = subparsers.add_parser('tracking', aliases=['t', 'trk'], parents=[no_case_parser, pkg_version_parser, select_parser, dialog_parser, color_parser, repository_parser, debug_parser],
                                             help='Display and tracking the packages dependencies.')
     tracking_parser.add_argument('packages', nargs='+', metavar='PACKAGE', help='Package names for tracking.')
     subparsers_map['tracking'] = tracking_parser
 
-    changelog_parser = subparsers.add_parser('changelog', parents=[edit_parser, pager_parser, repository_parser, query_parser, color_parser, debug_parser], help='Display the changelog for a given repository.')
+    changelog_parser = subparsers.add_parser('changelog', aliases=['a', 'chg'], parents=[edit_parser, pager_parser, repository_parser, query_parser, color_parser, debug_parser], help='Display the changelog for a given repository.')
     subparsers_map['changelog'] = changelog_parser
 
-    version_parser = subparsers.add_parser('version', parents=[], help='Show version and exit.')
+    version_parser = subparsers.add_parser('version', aliases=['v', 'ver'], parents=[], help='Show version and exit.')
     subparsers_map['version'] = version_parser
 
-    help_parser = subparsers.add_parser('help', parents=[], help='Show this help message and exit.')
+    help_parser = subparsers.add_parser('help', aliases=['h', 'hlp'], parents=[], help='Show this help message and exit.')
     help_parser.add_argument('command_for_help', nargs='?', help='Show help for a specific command.')
     subparsers_map['help'] = help_parser  # Store reference for 'help' itself
 
@@ -914,23 +932,23 @@ def main() -> None:  # pylint: disable=[R0912,R0914,R0915]
 
     # --- Command Dispatch ---
     command_map: dict[str, Callable[..., Any]] = {
-        'update': runner.update,
-        'upgrade': runner.upgrade,
-        'config': runner.edit_configs,
-        'repo-info': runner.repo_info,
-        'clean-tmp': runner.clean_tmp,
-        'self-check': runner.self_check,
-        'build': runner.build,
-        'install': runner.install,
-        'remove': runner.remove,
-        'download': runner.download,
-        'list': runner.list_installed,
-        'info': runner.info_package,
-        'search': runner.search,
-        'dependees': runner.dependees,
-        'tracking': runner.tracking,
-        'changelog': runner.changelog_print,
-        'version': runner.version
+        'update': runner.update, 'u': runner.update, 'upd': runner.update,
+        'upgrade': runner.upgrade, 'U': runner.upgrade, 'upg': runner.upgrade,
+        'config': runner.edit_configs, 'g': runner.edit_configs, 'conf': runner.edit_configs,
+        'repo-info': runner.repo_info, 'ri': runner.repo_info, 'rinf': runner.repo_info,
+        'clean-tmp': runner.clean_tmp, 'c': runner.clean_tmp, 'ctmp': runner.clean_tmp,
+        'self-check': runner.self_check, 'sc': runner.self_check, 'schk': runner.self_check,
+        'build': runner.build, 'b': runner.build, 'bld': runner.build,
+        'install': runner.install, 'i': runner.install, 'inst': runner.install,
+        'remove': runner.remove, 'R': runner.remove, 'rmv': runner.remove,
+        'download': runner.download, 'dl': runner.download, 'dwn': runner.download,
+        'list': runner.list_installed, 'l': runner.list_installed, 'lst': runner.list_installed,
+        'info': runner.info_package, 'inf': runner.info_package, 'show': runner.info_package,
+        'search': runner.search, 's': runner.search, 'ser': runner.search,
+        'dependees': runner.dependees, 'dp': runner.dependees, 'dps': runner.dependees,
+        'tracking': runner.tracking, 't': runner.tracking, 'trk': runner.tracking,
+        'changelog': runner.changelog_print, 'a': runner.changelog_print, 'chg': runner.changelog_print,
+        'version': runner.version, 'v': runner.version, 'ver': runner.version
     }
     logger.debug("Command map created: %s", list(command_map.keys()))
 
@@ -939,16 +957,16 @@ def main() -> None:  # pylint: disable=[R0912,R0914,R0915]
         logger.info("Dispatching command: '%s'", command)
 
         if command in commands_that_use_packages:
-            if command == 'download':
+            if command in ['download', 'dl', 'dwn']:
                 logger.info("Dispatching 'download' command with packages: %s, directory: %s", args.packages, directory)
                 runner.download(args.packages, directory)
             else:
                 logger.info("Dispatching command '%s' with packages: %s", command, args.packages)
                 command_map[command](args.packages)
-        elif command == 'changelog':
+        elif command in ['changelog', 'a', 'chg']:
             logger.info("Dispatching 'changelog' command with query: '%s'", query)
             runner.changelog_print(query)
-        elif command == 'help':
+        elif command in ['help', 'h', 'hlp']:
             logger.info("Handling 'help' command for subcommand: %s", args.command_for_help)
             # Specific handling for the 'help' command.
             if args.command_for_help:
