@@ -106,6 +106,13 @@ class Repositories:  # pylint: disable=[R0902, R0903]
     slack_patches_repo_mirror_changelog: str = ''
     slack_patches_repo_tag: str = ''
 
+    slack_testing_repo: bool = False
+    slack_testing_repo_name: str = 'slack_testing'
+    slack_testing_repo_path: Path = Path(repositories_path, slack_testing_repo_name)
+    slack_testing_repo_mirror_packages: str = ''
+    slack_testing_repo_mirror_changelog: str = ''
+    slack_testing_repo_tag: str = ''
+
     alien_repo: bool = False
     alien_repo_name: str = 'alien'
     alien_repo_path: Path = Path(repositories_path, alien_repo_name)
@@ -133,6 +140,12 @@ class Repositories:  # pylint: disable=[R0902, R0903]
     gnome_repo_mirror: str = ''
     gnome_repo_tag: str = 'gfs'
 
+    cosmic_repo: bool = False
+    cosmic_repo_name: str = 'cosmic'
+    cosmic_repo_path: Path = Path(repositories_path, cosmic_repo_name)
+    cosmic_repo_mirror: str = ''
+    cosmic_repo_tag: str = 'cosmic'
+
     msb_repo: bool = False
     msb_repo_name: str = 'msb'
     msb_repo_path: Path = Path(repositories_path, msb_repo_name)
@@ -277,6 +290,14 @@ class Repositories:  # pylint: disable=[R0902, R0903]
             logger.debug("SLACK_PATCHES config: Enabled=%s, Packages Mirror=%s, Changelog Mirror=%s",
                          slack_patches_repo, slack_patches_repo_mirror_packages, slack_patches_repo_mirror_changelog)
 
+            # SLACK_TESTING Repository
+            slack_testing_repo = bool(repos_config['SLACK_TESTING']['ENABLE'])
+            slack_testing_repo_url = repos_config['SLACK_TESTING']['MIRROR']
+            slack_testing_repo_mirror_packages = slack_testing_repo_url
+            slack_testing_repo_mirror_changelog = f"{'/'.join(slack_testing_repo_url.split('/')[:-2])}/"
+            logger.debug("SLACK_TESTING config: Enabled=%s, Packages Mirror=%s, Changelog Mirror=%s",
+                         slack_testing_repo, slack_testing_repo_mirror_packages, slack_testing_repo_mirror_changelog)
+
             # ALIEN Repository
             alien_repo = bool(repos_config['ALIEN']['ENABLE'])
             alien_repo_url = repos_config['ALIEN']['MIRROR']
@@ -306,6 +327,11 @@ class Repositories:  # pylint: disable=[R0902, R0903]
             gnome_repo_mirror = repos_config['GNOME']['MIRROR']
             logger.debug("GNOME config: Enabled=%s, Mirror=%s", gnome_repo, gnome_repo_mirror)
 
+            # COSMIC Repository
+            cosmic_repo = bool(repos_config['COSMIC']['ENABLE'])
+            cosmic_repo_mirror = repos_config['COSMIC']['MIRROR']
+            logger.debug("COSMIC config: Enabled=%s, Mirror=%s", cosmic_repo, cosmic_repo_mirror)
+
             # MSB Repository
             msb_repo = bool(repos_config['MSB']['ENABLE'])
             msb_repo_url = repos_config['MSB']['MIRROR']
@@ -426,6 +452,16 @@ class Repositories:  # pylint: disable=[R0902, R0903]
             'changelog_txt': changelog_txt,
             'repo_tag': slack_patches_repo_tag},
 
+        slack_testing_repo_name: {
+            'enable': slack_testing_repo,
+            'path': slack_testing_repo_path,
+            'mirror_packages': slack_testing_repo_mirror_packages,
+            'mirror_changelog': slack_testing_repo_mirror_changelog,
+            'packages_txt': packages_txt,
+            'checksums_md5': checksums_md5,
+            'changelog_txt': changelog_txt,
+            'repo_tag': slack_testing_repo_tag},
+
         alien_repo_name: {
             'enable': alien_repo,
             'path': alien_repo_path,
@@ -466,6 +502,16 @@ class Repositories:  # pylint: disable=[R0902, R0903]
             'changelog_txt': changelog_txt,
             'repo_tag': gnome_repo_tag},
 
+        cosmic_repo_name: {
+            'enable': cosmic_repo,
+            'path': cosmic_repo_path,
+            'mirror_packages': cosmic_repo_mirror,
+            'mirror_changelog': cosmic_repo_mirror,
+            'packages_txt': packages_txt,
+            'checksums_md5': checksums_md5,
+            'changelog_txt': changelog_txt,
+            'repo_tag': cosmic_repo_tag},
+
         msb_repo_name: {
             'enable': msb_repo,
             'path': msb_repo_path,
