@@ -44,8 +44,9 @@ class TerminalSelector:  # pylint: disable=[R0902,R0903]
         self.back_white = config_load.back_white
         self.back_grey = config_load.back_grey
         self.grey = config_load.grey
-        self.yellow = config_load.yellow
         self.red = config_load.red
+        self.yellow = config_load.yellow
+        self.green = config_load.green
         self.black = config_load.black
         self.hg = f"{self.back_white}{self.black}"
         self.endc = config_load.endc
@@ -241,7 +242,7 @@ class TerminalSelector:  # pylint: disable=[R0902,R0903]
         ec = self.endc
         message_length: int = 74  # instructions_message length without ASCII escape colour codes.
         balance_length: int = self.columns - message_length
-        instructions_message: str = f"{bg}Press {ec}{gr}[SPACE]{bg}, {ec}{gr}[TAB]{bg} for multi-selection and {ec}{gr}[ENTER]{bg} to select and accept.{" " * balance_length}{ec}"
+        instructions_message: str = f"{bg}Press {ec}{gr}[SPACE]{bg}, {ec}{gr}[TAB]{bg} for multi-selection and {ec}{gr}[ENTER]{bg} to select and accept.{' ' * balance_length}{ec}"
         sys.stdout.write(instructions_message)
 
         self._move_cursor_to(2, 1)
@@ -275,14 +276,22 @@ class TerminalSelector:  # pylint: disable=[R0902,R0903]
 
         display_string_item = ""
         if self.is_upgrade:
+            arrow: str = " -> "
             installed_version: str = self._installed_pkg_version(item_display)
             repo_pkg_version: str = self._repo_pkg_version(item_display)
-            repo_build: str = self._repo_pkg_build(item_display)
-            installed_build: str = self._installed_pkg_build(item_display)
+            repo_build: str = f"({self._repo_pkg_build(item_display)})"
+            installed_build: str = f" ({self._installed_pkg_build(item_display)})"
+
+            if not installed_version:
+                installed_version = f"{self.green}<- Add{self.endc} New Package "
+                installed_build = ""
+                repo_pkg_version = ""
+                repo_build = ""
+                arrow = ""
 
             inst_package_display: str = ""
             if installed_version:
-                inst_package_display = f"{installed_version} ({installed_build}) -> "
+                inst_package_display = f"{installed_version}{installed_build}{arrow}"
 
             # Use longest_name for dynamic padding, and apply highlight color if applicable
             pkg_name_formatted = f"{item_display:<{self.longest_name}}"
@@ -290,7 +299,7 @@ class TerminalSelector:  # pylint: disable=[R0902,R0903]
                 pkg_name_formatted = f"{self.hg}{pkg_name_formatted}{self.endc}"
 
             display_string_item = (f"{prefix}{checkbox} {pkg_name_formatted} {inst_package_display}"
-                                   f"{self.yellow}{repo_pkg_version} ({repo_build}){self.endc}")
+                                   f"{self.yellow}{repo_pkg_version} {repo_build}{self.endc}")
         else:
             pkg_name_formatted = item_display
             if self.colors and is_current_selection:
